/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSActivityModel.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 4/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSActivityModel.h"

@implementation XPSActivityModel

@synthesize photo = _photo;

-(UIImage *)photo
{
    
    //LAZY LOAD
    if(_photo == nil) {
        
        //CARREGUEM IMATGE AMB LA URL OBTINGUDA DE LA BASE DE DADES DE LA GENERALITAT
        _photo = [UIImage imageWithData:[NSData dataWithContentsOfURL:self.photoURL]];
        
        //EN CAS QUE NO HI HAGI COMPROVEM SI S'HA CANVIAT LA RUTA DE LA IMATGE I HO TORNEM A PROVAR
        if (_photo == nil) {
            NSString *url = [NSString stringWithFormat:@"%@", self.photoURL];
            NSRange agenda = [url rangeOfString:@"agenda/"];
            
            if (agenda.location != NSNotFound) {
                url = [url stringByReplacingCharactersInRange:agenda withString:@""];
            }
            
            NSURL *theURL = [NSURL URLWithString:url];
            
            _photo = [UIImage imageWithData:[NSData dataWithContentsOfURL:theURL]];
        }
        
        //SI ENCARA NO TENIM IMATGE CARREGUEM UNA PROPIA PER NO DEIXAR BUIT L'ESPAI
        if (_photo == nil) {
            _photo = [UIImage imageWithData:[NSData dataWithContentsOfURL:[NSURL URLWithString:@"http://gacc.esy.es/image.png"]]];
        }
        
    }
    
    return _photo;
    
}

//INICIALITZADOR DE CONVENIENCIA
-(id) initWithName: (NSString *)name
                pk: (NSString *)pk
       description: (NSString *)descript
          initDate: (NSString *)initialDate
           endDate: (NSString *)endDate
          schedule: (NSString *)schedule
             place: (NSString *)place
           address: (NSString *)address
              city: (NSString *)city
           comarca: (NSString *)comarca
        postalCode: (NSString *)cp
             phone: (NSString *)phone
               web: (NSString *)url
             price: (NSString *)price
          category: (NSString *)category
             photo: (NSURL *)photoURL
          distance: (NSNumber *)distance
{
    
    if (self = [super init]) {
        _name = name;
        _pk = pk;
        _descript = descript;
        _initialDate = initialDate;
        _endDate = endDate;
        _schedule = schedule;
        _place = place;
        _address = address;
        _city = city;
        _comarca = comarca;
        _cp = cp;
        _phone = phone;
        _url = url;
        _price = price;
        _category = category;
        _photoURL = photoURL;
        _distance = distance;
        
    }
    
    return self;
    
}

//INICIALITZADOR USAT PER CREAR OBJECTES DE TIPUS ACTIVITAT SEGONS DADES OBTINGUDES DEL WEBSERVICE
-(id) initwithDictionary: (NSDictionary *)aDict
{
    
    return [self initWithName:[aDict objectForKey:@"nom_activitat"]
                           pk:[aDict objectForKey:@"pk_activitat"]
                  description:[aDict objectForKey:@"descripcio_activitat"]
                     initDate:[aDict objectForKey:@"data_inici_activitat"]
                      endDate:[aDict objectForKey:@"data_fi_activitat"]
                     schedule:[aDict objectForKey:@"horari_activitat"]
                        place:[aDict objectForKey:@"lloc_activitat"]
                      address:[aDict objectForKey:@"adreca_activitat"]
                         city:[aDict objectForKey:@"poblacio_activitat"]
                      comarca:[aDict objectForKey:@"comarca_activitat"]
                   postalCode:[aDict objectForKey:@"cp_activitat"]
                        phone:[aDict objectForKey:@"telefons_activitat"]
                          web:[aDict objectForKey:@"web_activitat"]
                        price:[aDict objectForKey:@"entrades_activitat"]
                     category:[aDict objectForKey:@"categoria_activitat"]
                        photo:[NSURL URLWithString: [aDict objectForKey:@"imatge_activitat"]]
                     distance:[aDict objectForKey:@"distancia_activitat"]];
    
}


//NECESSARI PER GUARDAR OBJECTES A NSURLDEFAULTS
- (void)encodeWithCoder:(NSCoder *)encoder
{
    [encoder encodeObject:self.name forKey:@"nameKey"];
    [encoder encodeObject:self.pk forKey:@"pkKey"];
    [encoder encodeObject:self.descript forKey:@"descriptKey"];
    
    [encoder encodeObject:self.initialDate forKey:@"initialDateKey"];
    [encoder encodeObject:self.endDate forKey:@"endDateKey"];
    [encoder encodeObject:self.schedule forKey:@"scheduleKey"];
    [encoder encodeObject:self.place forKey:@"placeKey"];
    [encoder encodeObject:self.address forKey:@"addressKey"];
    [encoder encodeObject:self.city forKey:@"cityKey"];
    [encoder encodeObject:self.comarca forKey:@"comarcaKey"];
    [encoder encodeObject:self.cp forKey:@"cpKey"];
    [encoder encodeObject:self.phone forKey:@"phoneKey"];
    [encoder encodeObject:self.url forKey:@"urlKey"];
    [encoder encodeObject:self.price forKey:@"priceKey"];
    [encoder encodeObject:self.category forKey:@"categoryKey"];
    [encoder encodeObject:self.photoURL forKey:@"photoURLKey"];
    [encoder encodeObject:self.distance forKey:@"distanceKey"];
}

//NECESSARI PER OBTENIR OBJECTES DE NSURLDEFAULTS
- (id)initWithCoder:(NSCoder *)decoder
{
    if((self = [super init]))
    {
        self.name = [decoder decodeObjectForKey:@"nameKey"];
        self.pk = [decoder decodeObjectForKey:@"pkKey"];
        self.descript = [decoder decodeObjectForKey:@"descriptKey"];
        
        self.initialDate = [decoder decodeObjectForKey:@"initialDateKey"];
        self.endDate = [decoder decodeObjectForKey:@"endDateKey"];
        self.schedule = [decoder decodeObjectForKey:@"scheduleKey"];
        self.place = [decoder decodeObjectForKey:@"placeKey"];
        self.address = [decoder decodeObjectForKey:@"addressKey"];
        self.city = [decoder decodeObjectForKey:@"cityKey"];
        self.comarca = [decoder decodeObjectForKey:@"comarcaKey"];
        self.cp = [decoder decodeObjectForKey:@"cpKey"];
        self.phone = [decoder decodeObjectForKey:@"phoneKey"];
        self.url = [decoder decodeObjectForKey:@"urlKey"];
        self.price = [decoder decodeObjectForKey:@"priceKey"];
        self.category = [decoder decodeObjectForKey:@"categoryKey"];
        self.photoURL = [decoder decodeObjectForKey:@"photoURLKey"];
        self.distance = [decoder decodeObjectForKey:@"distanceKey"];
        
        
    }
    return self;
}

@end
