/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSActivityViewController.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 4/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSActivityViewController.h"
#import "XPSMapViewController.h"
#import "XPSActivityModel.h"

@interface XPSActivityViewController ()

//CONTROLEM SI L'ACTIVITAT ES FAVORITA O NO PER AFEGIR/ELIMINAR CADA COP QUE ES PREM EL BOTO FAVORIT
@property BOOL fav;

//FEEDBACK PER L'USUARI PER QUE SAPIGA QUE L'APLICA ESTÀ CARREGANT LES DADES
@property (strong, nonatomic) UIActivityIndicatorView *ai;

@end

@implementation XPSActivityViewController

- (id)initWithModel:(XPSActivityModel *)aModel
{
    
    if (self = [super initWithNibName:nil bundle:nil]) {
        _model = aModel;
        self.title = @"Activitat";
    }
    
    return self;
    
}

-(void) viewDidLoad
{
    [super viewDidLoad];
    
    self.navigationController.navigationBar.tintColor = [UIColor whiteColor];
    
}

-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    //COMPROBA SI L'USUARI HA FET LOGIN I DONA COLOR AL BOTÓ FAVORIT
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    NSString *user = [defaults objectForKey:@"userMail"];
    
    if (user) { //USUARI HA FET LOGIN
        
        //RECUPERA DADES FAVORITS NSUSERDEFAULTS
        NSData *encodedData = [defaults objectForKey:@"favorits"];
        NSMutableArray *favorites = (NSMutableArray *)[NSKeyedUnarchiver unarchiveObjectWithData:encodedData];
        
        //RECORRE FAVORITS PER MARCAR EL COLOR DEL BOTÓ SEGONS CONVINGUI
        for (XPSActivityModel *favorite in favorites) {
            
            XPSActivityViewController *activity = [[XPSActivityViewController alloc] initWithModel:favorite];
            
            if ([activity.model.pk isEqualToString:self.model.pk]) { //ACTIVITAT FAVORITA
                
                //[self.favorite setTitleColor:[UIColor colorWithRed:1 green:0 blue:0 alpha:1] forState:UIControlStateNormal]; //COLOR VERMELL
                [self.favorite setTintColor:[UIColor yellowColor]];
                self.fav = YES;
                break;
                
            } else { //ACTIVITAT NO FAVORITA
                
                //[self.favorite setTitleColor:[UIColor colorWithRed:0 green:0 blue:0 alpha:1] forState:UIControlStateNormal]; //COLOR NEGRE
                [self.favorite setTintColor:[UIColor blueColor]];
                self.fav = NO;
            }
            
        }
        
        
    } else { //USUARI NO HA FET LOGIN
        
        [self.favorite setTitleColor:[UIColor colorWithRed:0 green:0 blue:0 alpha:1] forState:UIControlStateNormal];
        self.fav = NO;
        
    }
    
    [self sync];
}

//SINCRONITZA LES DADES DEL MODEL AMB LES QUE ES MOSTREN A LA VISTA CADA VEGADA QUE S'EXECUTA viewWillAppear
-(void)sync
{
   
    //FORMAT DE DATA INICI
    NSArray *words = [self.model.initialDate componentsSeparatedByString:@" "];
    NSString *initialDate = [words objectAtIndex:0];
    words = [initialDate componentsSeparatedByString:@"-"];
    initialDate = [NSString stringWithFormat:@"%@ %@ %@", [words objectAtIndex:2], [words objectAtIndex:1], [words objectAtIndex:0]];
    
    //FORMAT DE DATA FI
    words = [self.model.endDate componentsSeparatedByString:@" "];
    NSString *endDate = [words objectAtIndex:0];
    words = [endDate componentsSeparatedByString:@"-"];
    endDate = [NSString stringWithFormat:@"%@ %@ %@", [words objectAtIndex:2], [words objectAtIndex:1], [words objectAtIndex:0]];
    
    //FORMAT ADRESSA I INFORMACIÓ
    NSString *completeAddress = [NSString stringWithFormat:@"%@\n%@ %@", self.model.place, self.model.address, self.model.city];
    NSString *contactInformation = [NSString stringWithFormat:@"Del %@ al %@\n%@\n%@ %@", initialDate, endDate, self.model.schedule, self.model.phone, self.model.url];
    
    //SINCRONITZACIÓ DADES
    self.address.text = completeAddress;
    self.contact.text = contactInformation;
    self.name.text = self.model.name;
    if (self.model.photo == nil) {
        self.photo.image = [UIImage imageWithData:[NSData dataWithContentsOfURL:[NSURL URLWithString:@"http://gacc.esy.es/image.png"]]];
    } else {
        self.photo.image = self.model.photo;
    }
    
    if ([self.model.price isEqualToString:@""]) {
        self.price.text = @"No disponible";
    } else {
        self.price.text = self.model.price;
    }
    
    self.descript.text = self.model.descript;
    
    
}

//MOSTRA LA VISTA DEL MAPA PASSANT L'ADREÇA DE L'ACTIVITAT
-(IBAction)displayMap:(id)sender
{
    NSString *address;
    NSMutableString *totalAddress = [[NSMutableString alloc] initWithString:self.model.address];
    totalAddress = [[totalAddress stringByAppendingString:@","] mutableCopy];
    totalAddress = [[totalAddress stringByAppendingString:self.model.city] mutableCopy];
    address = totalAddress;
    
    XPSMapViewController *mapVC = [[XPSMapViewController alloc] initWithAddress:address];
    
    [self.navigationController pushViewController:mapVC animated:YES];
    
}

//GESTIONA ELS FAVORITS
-(IBAction)manageFavorite:(id)sender
{
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    
    if ([defaults objectForKey:@"userMail"]) { //L'USUARI ESTÀ IDENTIFICAT
        
        if (self.fav) { //LA ACTIVITAT ÉS FAVORITA PER TANT CAL ESBORRAR-LA DE LA LLISTA DE FAVORITS
            
            //PREPARACIO SOL·LICITUD AL SERVEI WEB ELIMINAR ACTIVITAT FAVORITA
            NSString *userData = [NSString stringWithFormat:@"user=%@&pk=%@&action=delete", [defaults objectForKey:@"userMail"], self.model.pk];
            NSData *postUserData = [userData dataUsingEncoding:NSUTF8StringEncoding];
            NSString *postLength = [NSString stringWithFormat:@"%lu", (unsigned long)[postUserData length]];
            
            NSMutableURLRequest *request = [[NSMutableURLRequest alloc] init];
            [request setURL:[NSURL URLWithString:@"http://gacc.esy.es/favorites.php"]];
            [request setHTTPMethod:@"POST"];
            [request setValue:postLength forHTTPHeaderField:@"Content-Length"];
            [request setValue:@"application/x-www-form-urlencoded" forHTTPHeaderField:@"Content-Type"];
            [request setHTTPBody:postUserData];
            
            //CONNEXIO ASÍNCRONA
            NSURLConnection *conn = [[NSURLConnection alloc] initWithRequest:request delegate:self];
            [conn start];
            
            //INDICADOR PER DONCAR FEEDBACK A L'USUARI QUE S'ESTAN CARREGANT LES DADES
            self.ai = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
            self.ai.frame = CGRectMake(self.view.frame.size.width / 2.0, (self.view.frame.size.height / 2) - 150, 0, 0);
            CGAffineTransform transform = CGAffineTransformMakeScale(2.0f, 2.0f);
            self.ai.transform = transform;
            [self.ai startAnimating];
            [self.view addSubview:self.ai];
            

        } else { //LA ACTIVITAT NO ÉS FAVORITA PER TANT CAL AFEGIR-LA A LA LLISTA DE FAVORITS
            
            //PREPARACIO SOL·LICITUD AL SERVEI WEB AFEGIR ACTIVITAT FAVORITAT
            NSString *userData = [NSString stringWithFormat:@"user=%@&pk=%@&action=insert", [defaults objectForKey:@"userMail"], self.model.pk];
            NSData *postUserData = [userData dataUsingEncoding:NSUTF8StringEncoding];
            NSString *postLength = [NSString stringWithFormat:@"%lu", (unsigned long)[postUserData length]];
            
            NSMutableURLRequest *request = [[NSMutableURLRequest alloc] init];
            [request setURL:[NSURL URLWithString:@"http://gacc.esy.es/favorites.php"]];
            [request setHTTPMethod:@"POST"];
            [request setValue:postLength forHTTPHeaderField:@"Content-Length"];
            [request setValue:@"application/x-www-form-urlencoded" forHTTPHeaderField:@"Content-Type"];
            [request setHTTPBody:postUserData];
            
            //CONNEXIO ASÍNCRONA
            NSURLConnection *conn = [[NSURLConnection alloc] initWithRequest:request delegate:self];
            [conn start];
            
            //INDICADOR PER DONCAR FEEDBACK A L'USUARI QUE S'ESTAN CARREGANT LES DADES
            self.ai = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
            self.ai.frame = CGRectMake(self.view.frame.size.width / 2.0, (self.view.frame.size.height / 2) - 150, 0, 0);
            CGAffineTransform transform = CGAffineTransformMakeScale(2.0f, 2.0f);
            self.ai.transform = transform;
            [self.ai startAnimating];
            [self.view addSubview:self.ai];
            
        }
             
        
    } else { //USUARI SENSE IDENTIFICAR. NO POT GESTIONAR FAVORITS
        
        //MOSTRA MISSATGE INFORMATIU
        UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                           message:@"Cal estar registrat per gestionar els favorits"
                                                          delegate:self
                                                 cancelButtonTitle:@"OK"
                                                 otherButtonTitles:nil];
        [theAlert show];
        
        
    }
    
}

-(IBAction)sendMail:(id)sender
{
    MFMailComposeViewController *mailVC = [[MFMailComposeViewController alloc] init];
    mailVC.mailComposeDelegate = self;
    NSString *subject = @"Recomanació activitat";
    NSString *body = [NSString stringWithFormat:@"Títol:\n%@\n\nDescripció:\n%@\n\nLloc:\n%@\n\nAdreça:\n%@ %@\n\nContacte:\n%@ \n%@ \n\nPreu:\n%@", self.model.name, self.model.descript, self.model.place, self.model.address, self.model.city, self.model.phone, self.model.url, self.model.price];
    
    [mailVC setSubject:subject];
    [mailVC setMessageBody:body isHTML:NO];
    [self presentViewController:mailVC animated:YES completion:nil];
    
    
}

#pragma mark - MFMailComposeViewControllerDelegate

-(void)mailComposeController:(MFMailComposeViewController *)controller didFinishWithResult:(MFMailComposeResult)result error:(NSError *)error
{

    [self dismissViewControllerAnimated:YES completion:nil];

}

#pragma mark NSURLConnection Delegate Methods

-(void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response
{
    self.responseData = [[NSMutableData alloc] init];
}

-(void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data
{
    [self.responseData appendData:data];
}

-(NSCachedURLResponse *)connection:(NSURLConnection *)connection willCacheResponse:(NSCachedURLResponse *)cachedResponse
{
    return nil;
}

-(void)connectionDidFinishLoading:(NSURLConnection *)connection
{
    //DADES REBUDES PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    NSError *error;
    
    if (self.fav) { //SI LA ACTIVITAT ES FAVORITA ES FA LA SEVA ELIMINACIÓ
        
        if (self.responseData != nil) { //S'HAN REBUT DADES
            
            //OBTENIM EL VALOR DE LES DADES REBUDES
            NSString *valor = [NSJSONSerialization JSONObjectWithData:self.responseData
                                                              options:NSJSONReadingAllowFragments
                                                                error:&error];
            
            if (valor != nil) { //VALOR VÀLID
                
                //RECUPEREM DADES ACTIVITATS DE NSUSERDEFAULTS PER ELIMINAR ACTIVITAT FAVORITA
                NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
                NSData *encodedData = [defaults objectForKey:@"favorits"];
                NSMutableArray *favorites = (NSMutableArray *)[NSKeyedUnarchiver unarchiveObjectWithData:encodedData];
                
                for (XPSActivityModel *favorite in favorites) {
                    
                    XPSActivityViewController *activity = [[XPSActivityViewController alloc] initWithModel:favorite];
                    
                    if ([activity.model.pk isEqualToString:self.model.pk]) {
                        [favorites removeObject:favorite];
                        NSData *encodedArray = [NSKeyedArchiver archivedDataWithRootObject:favorites];
                        [defaults setObject:encodedArray forKey:@"favorits"];
                        break;
                    }
                    
                }
                
                //SINCRONITZAR AMB NSUSERDEFAULTS PER EVITAR POSSIBLES INCONSISTENCIES
                [defaults synchronize];
                
                //ACTUALITZAR COLOR DEL BOTÓ FAVORIT
                //[self.favorite setTitleColor:[UIColor colorWithRed:0 green:0 blue:0 alpha:1] forState:UIControlStateNormal];
                [self.favorite setTintColor:[UIColor blueColor]];
                
                //CANVIAR ESTAT DE FAVORIT
                self.fav = NO;
                
            }
            
        }
        
    } else { //LA ACTIVITAT NO ES FAVORITA PER TANT CAL AFEGIR-LA
        
        if (self.responseData != nil) { //S'HAN REBUT DADES
            
            //OBTENIM EL VALOR DE LES DADES REBUDES
            NSString *valor = [NSJSONSerialization JSONObjectWithData:self.responseData
                                                              options:NSJSONReadingAllowFragments
                                                                error:&error];
            
            if (valor != nil) { //VALOR VÀLID
                
                //RECUPEREM DADES ACTIVITATS DE NSUSERDEFAULTS PER AFEGIR LA ACTIVITAT FAVORITA
                NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
                NSData *encodedData = [defaults objectForKey:@"favorits"];
                NSMutableArray *favorites = (NSMutableArray *)[NSKeyedUnarchiver unarchiveObjectWithData:encodedData];
                [favorites addObject:self.model];
                NSData *encodedArray = [NSKeyedArchiver archivedDataWithRootObject:favorites];
                [defaults setObject:encodedArray forKey:@"favorits"];
                
                //SINCRONITZAR AMB NSUSERDEFAULTS PER EVITAR POSSIBLES INCONSISTENCIES
                [defaults synchronize];
                
                //ACTUALITZAR COLOR DEL BOTÓ FAVORIT
                //[self.favorite.titleLabel setTintColor:[UIColor yellowColor]];
                [self.favorite setTintColor:[UIColor yellowColor]];
                
                //CANVIAR ESTAT DE FAVORIT
                self.fav = YES;
                
                
            }
            
            
        }
        
        
    }
    
}

-(void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error
{
    //ERROR PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    //MOSTRAR MISSATGE DE ERROR
    UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                       message:@"Problema amb la connexió. No s'ha pogut afegir/eliminar el favorit"
                                                      delegate:self
                                             cancelButtonTitle:@"OK"
                                             otherButtonTitles:nil];
    [theAlert show];
}


@end
