/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSCercaTableTableViewController.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 6/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSCercaTableTableViewController.h"
#import "XPSActivityModel.h"
#import "XPSActivitiesListTableViewController.h"

@interface XPSCercaTableTableViewController () <OptionsSearchTableViewControllerDelegate>

//GESTIÓ DE UIDATEPICKER
@property BOOL desplegat;
@property BOOL visible;
@property BOOL hidden;
@property (nonatomic, strong) UIDatePicker *datePicker;

//FEEDBACK PER L'USUARI PER QUE SAPIGA QUE L'APLICA ESTÀ CARREGANT LES DADES
@property (strong, nonatomic) UIActivityIndicatorView *ai;

@end

@implementation XPSCercaTableTableViewController

-(id)initWithStyle:(UITableViewStyle)style
{
    //ASSIGNEM TÍTOL I IMATGE PER L'ITEM DEL TAB BAR
    if (self = [super initWithStyle:style]) {
        self.title = @"Cerca";
        [self.tabBarItem setImage:[UIImage imageNamed:@"search"]];
        
        [self.tabBarItem setImage:[[UIImage imageNamed:@"search"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
        [self.tabBarItem setSelectedImage:[[UIImage imageNamed:@"searchB"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
        [self.tabBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: [UIColor blackColor]} forState:UIControlStateNormal];
        [self.tabBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: [UIColor whiteColor]} forState:UIControlStateSelected];
        
    }
    
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    //BOTÓ PER BUSCAR ACTIVITATS
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Buscar" style:UIBarButtonItemStylePlain target:self action:@selector(searchActivities)];
    self.navigationItem.rightBarButtonItem.tintColor = [UIColor whiteColor];
    
    //INICIEM EL DATE PICKER
    self.datePicker = [[UIDatePicker alloc] init];
    self.datePicker.datePickerMode = UIDatePickerModeDate;
    
    //DATA INICIADA A QUALSEVOL
    self.date = @"Totes";
    self.provincia = @"tots";
    self.poble = @"tots";
    
    //ACTUALITZACIÓ DE LA DATA CADA VEGADA QUE CANVI DE VALOR
    [self.datePicker addTarget:self action:@selector(setCurrentDate:) forControlEvents:UIControlEventValueChanged];
    
    //ESTAT INICIAL
    self.desplegat = NO;
    self.visible = NO;
    
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void) viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {

    // Return the number of sections.
    return 3;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    // Return the number of rows in the section.
    if (section == ON_SECTION) {
        return 2;
    } else if (section == QUAN_SECTION) {
        return 3;
    } else {
        return 1;
    }
}


- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *cellIdentifier = @"ident";
    
    //REUTILITZEM CELLS SI N'HI HA
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier];
    
    //CREA NOVA CELL SI NO S'EN POT REAPROFITAR CAP ALTRE
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellIdentifier];
    }
    
    //TITOLS CELLS SEGONS SECCIÓ I FILA
    if (indexPath.section == ON_SECTION) {
        
        if (indexPath.row == 0) {
            
            cell.textLabel.text = [NSString stringWithFormat:@"Provincia: %@", self.provincia];

        } else if (indexPath.row == 1) {
            
            cell.textLabel.text = [NSString stringWithFormat:@"Població: %@", self.poble];

        }
        
        [cell setAccessoryType:UITableViewCellAccessoryDisclosureIndicator];
    
    } else if (indexPath.section == QUAN_SECTION && indexPath.row == 0) {
        
        if ([self.date isEqualToString:@"Totes"]) {
            cell.textLabel.text = [NSString stringWithFormat:@"Data: %@", self.date];
        }
        
        
    } else if (indexPath.section == QUAN_SECTION && indexPath.row == 1) {
        
        cell.textLabel.text = @"totes les dates";
        
        if (self.desplegat && [self.date isEqualToString:@"Totes"]) {
            [cell setAccessoryType:UITableViewCellAccessoryCheckmark];
        }
        
        
    } else if (indexPath.section == QUAN_SECTION && indexPath.row == 2) {
        
        //CONTROL DE L'ESTAT DEL DATE PICKER
        if (!self.desplegat) {
            
            cell.hidden = YES;
       
        } else {
            
            if (self.visible) {
                
                cell.hidden = NO;
                
            } else {
                
                [cell addSubview:self.datePicker];
                [cell setAccessoryType:UITableViewCellAccessoryNone];
                cell.hidden = NO;
                self.visible = YES;
                
            }
            
        }
        
    } else if (indexPath.section == CATEGORIA_SECTION) {
        
        cell.textLabel.text = @"Categoria";
        [cell setAccessoryType:UITableViewCellAccessoryDisclosureIndicator];
        
    }
    
    return cell;
}

- (NSString *)tableView:(UITableView *)tableView
titleForHeaderInSection:(NSInteger)section {
    
    //TÍTOLS DE CADA SECCIÓ DE LA TAULA
    if (section == ON_SECTION) {
        
        return @"On";
        
    } else if (section == QUAN_SECTION) {
        
        return @"Quan";
        
    } else {
        
        return @"De quin tipus";
        
    }
    
}

-(void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    
    if (indexPath.section == ON_SECTION && indexPath.row == 0) { //PROVINCIA
        
        //ARRAY AMB LES PROVINCIES
        NSArray *prov = [[NSArray alloc] initWithObjects:@"Totes les provincies",@"Barcelona", @"Girona", @"Lleida", @"Tarragona", nil];
        
        //SI NO HI HA CAP PROVINCIA SELECCIONADA ES MARCA LA PRIMERA OPCIÓ
        if (self.provinciaSelected == nil) {
            self.provinciaSelected = [NSIndexPath indexPathForItem:0 inSection:0];
        }
        
        //S'INICIA LA TAULA AMB LES DADES ANTERIORS
        XPSOptionsSearchTableViewController *provinciesVC = [[XPSOptionsSearchTableViewController alloc] initWithStyle:UITableViewStylePlain array:prov selected:self.provinciaSelected];
        provinciesVC.delegate = self;
        
        //ES MOSTRA LA TAULA DE PROVIINCIES
        [self.navigationController pushViewController:provinciesVC animated:YES];
        
    } else if (indexPath.section == ON_SECTION && indexPath.row == 1) { //POBLACIÓ
        
        //SI NO HI HA CAP POBLE SELECCIONAT ES MARCA LA PRIMERA OPCIÓ
        if (self.pobleSelected == nil) {
            self.pobleSelected = [NSIndexPath indexPathForItem:0 inSection:0];
        }
        
        //S'INICIA LA TAULA AMB LES DADES ANTERIORS
        XPSOptionsSearchTableViewController *poblesVC = [[XPSOptionsSearchTableViewController alloc] initWithStyle:UITableViewStylePlain withProvincia:self.provincia selected:self.pobleSelected];
        poblesVC.delegate = self;
        
        //ES MOSTRA LA TAULA DE POBLES
        [self.navigationController pushViewController:poblesVC animated:YES];
        
    } else if (indexPath.section == QUAN_SECTION && indexPath.row == 0) { //DATA
        
        //ACTUALITZACIÓ ESTAT CELL DATA
        self.desplegat = !self.desplegat;
        [self.tableView reloadRowsAtIndexPaths:@[[NSIndexPath indexPathForRow:1 inSection:QUAN_SECTION]] withRowAnimation:UITableViewRowAnimationFade];
        [self.tableView reloadData];
    
    } else if (indexPath.section == QUAN_SECTION && indexPath.row == 1) {
        
        self.date = @"Totes";
        UITableViewCell *cell = [tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:0 inSection:2]];
        cell.textLabel.text = [NSString stringWithFormat:@"Data: %@",self.date];
        
        UITableViewCell *currentCell = [tableView cellForRowAtIndexPath:indexPath];
        [currentCell setAccessoryType:UITableViewCellAccessoryCheckmark];
        
        
    }else if (indexPath.section == CATEGORIA_SECTION) { //CATEGORIA
        
        //SI NO HI HA CAP CATEGORIA SELECCIONADA ES MARCA LA PRIMERA OPCIÓ
        if (self.categorySelected == nil) {
            self.categorySelected = [NSIndexPath indexPathForItem:0 inSection:0];
        }
        
        //S'INICIA LA TAULA AMB LES DADES ANTERIORS
        XPSOptionsSearchTableViewController *categoriesVC = [[XPSOptionsSearchTableViewController alloc] initWithStyle:UITableViewStylePlain withProvincia:self.provincia withPoble:self.poble selected:self.categorySelected];
        categoriesVC.delegate = self;
        
        //ES MOSTRA LA TAULA DE CATEGORIES
        [self.navigationController pushViewController:categoriesVC animated:YES];
        
    }
    
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

-(CGFloat) tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    //ALÇADE DE CELLS SEGONS SI ÉS EL DATEPICKER O NO
    if (indexPath.section == QUAN_SECTION && indexPath.row == 1) {
        if (self.desplegat) {
            return 50;
        } else {
            return 0;
        }
    } else if (indexPath.section == QUAN_SECTION && indexPath.row == 2) {
        if (self.desplegat) {
            return 219;
        } else {
            return 0;
        }
    } else {
        return 50;
    }
}

-(CGFloat) tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section
{
    return 5;
}

-(CGFloat) tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section
{
    return 30;
}


#pragma mark - Utils

//MÈTODE PER ACTUALITZAR DATA CADA VEGADA QUE ES CANVIA AL DATE PICKER
-(void) setCurrentDate: (UIDatePicker *)sender
{
    
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:@"YYYY-MM-dd"];
    
    self.date = [dateFormatter stringFromDate:sender.date];
    
    UITableViewCell *cell = [self.tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:1 inSection:2]];
    [cell setAccessoryType:UITableViewCellAccessoryNone];
    
    UITableViewCell *cellDate = [self.tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:0 inSection:2]];
    [dateFormatter setDateFormat:@"dd MMMM YYYY"];
    cellDate.textLabel.text = [NSString stringWithFormat:@"Data: %@", [dateFormatter stringFromDate:sender.date]];

}

//MÈTODE PER BUSCAR ACTIVITATS SEGONS ELS FILTRES SELECCIONATS
-(void)searchActivities
{
    //PREPAREM URL PER AFEGIR FILTRES
    NSString *baseURL = [[NSMutableString alloc] initWithString:@"http://gacc.esy.es/consulta.php?"];
    
    if (self.category != nil) { //S'HA TRIAT UNA CATEGORIA
        
        //FORMAT DE LA CATEGORIA SI TE MÉS D'UNA PARAULA
        NSArray *words = [self.category componentsSeparatedByString:@" "];
        self.category = [words componentsJoinedByString:@"-"];
        
        //S'AFEGEIX LA CATEGORIA A LA URL
        baseURL = [baseURL stringByAppendingString:@"categoria="];
        baseURL = [baseURL stringByAppendingString:self.category];
        
    }
    
    if (self.provincia != nil) { //S'HA ESCOLLIT PROVINCIA
        
        if (!self.category) { //NO HI HA CATEGORIA
            
            baseURL = [baseURL stringByAppendingString:@"provincia="];
            
        } else { //JA HI HA CATEGORIA
            
            baseURL = [baseURL stringByAppendingString:@"&provincia="];
        
        }
        
        //AFEGIM PROVINCIA A LA URL
        baseURL = [baseURL stringByAppendingString:self.provincia];
        
    }
    
    if (self.poble != nil) { //S'HA ESCOLLIT UN POBLE
        
        //FORMAT DEL POBLE SI TÉ MÉS D'UNA PARAULA
        NSArray *words = [self.poble componentsSeparatedByString:@" "];
        self.poble = [words componentsJoinedByString:@"+"];
        
        //FORMAT DEL POBLE SI EL NOM CONTE CARÀCTERS AMB APÒSTROFS
        NSString *symbol = @"'";
        NSRange range = [self.poble rangeOfString:symbol options:NSCaseInsensitiveSearch];
        
        if (range.location != NSNotFound) {
            words = [self.poble componentsSeparatedByString:@"'"];
            self.poble = [words componentsJoinedByString:@"!"];
        }
        
        if (!self.category && !self.provincia) { //NO HI HA CATEGORIA NI PROVINCIA SELECCIONATS
            
            baseURL = [baseURL stringByAppendingString:@"poblacio="];
            
        } else { //S'HA SELECCIONAT UNA CATEGORIA O UN POBLE
            
            baseURL = [baseURL stringByAppendingString:@"&poblacio="];
        }
        
        //AFEGIM POBLE A LA URL
        baseURL = [baseURL stringByAppendingString:self.poble];
        
    }
    
    if (self.date != nil) { //S'HA ESCOLLIT UNA DATA
        
        if (!self.category && !self.provincia && !self.poble) { //NO S'HA ESCOLLIT CAP ALTRE FILTRE
            
            baseURL = [baseURL stringByAppendingString:@"data="];
        
        } else { //S'HA ESCOLLIT ALGUN ALTRE FILTRE
            
            baseURL = [baseURL stringByAppendingString:@"&data="];
        }
        
        //AFEGIM DATA A LA URL
        baseURL = [baseURL stringByAppendingString:self.date];
    
    } else { //NO S'HA ESCOLLIT CAP DATA S'UTILITZA LA DEL PROPI DIA
        
        //PREPAREM DATA
        NSDate *current = [NSDate date];
        NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
        [dateFormatter setDateFormat:@"YYYY-MM-dd"];
        NSString *activityDate = [dateFormatter stringFromDate:current];
        
        if (!self.category && !self.provincia && !self.poble) { //NO S'HA ESCOLLIT CAP ALTRE FILTRE
            
            baseURL = [baseURL stringByAppendingString:@"data="];
            
        } else { //S'HA ESCOLLIT ALGUN ALTRE FILTRE
            
            baseURL = [baseURL stringByAppendingString:@"&data="];
            
        }
        
        //AFEGIM DATA A LA URL
        baseURL = [baseURL stringByAppendingString:activityDate];
    
    }
    
    //PREPARACIO SOL·LICITUD AL SERVEI WEB BUSCAR ACTIVITATS
    NSURLRequest *request = [NSURLRequest requestWithURL:[NSURL URLWithString:[baseURL stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding]]];
    
    //CONNEXIO ASÍNCRONA
    NSURLConnection *conn = [[NSURLConnection alloc] initWithRequest:request delegate:self];
    [conn start];
    
    //INDICADOR PER DONCAR FEEDBACK A L'USUARI QUE S'ESTAN CARREGANT LES DADES
    self.ai = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    self.ai.frame = CGRectMake(self.view.frame.size.width / 2.0, (self.view.frame.size.height / 2) - 150, 0, 0);
    CGAffineTransform transform = CGAffineTransformMakeScale(2.0f, 2.0f);
    self.ai.transform = transform;
    [self.ai startAnimating];
    [self.view addSubview:self.ai];
    
    
}


#pragma mark - OptionsSearchTableViewControllerDelegate

//MÈTODE DELEGAT PER OBTENIR INFORMACIÓ DE LA PROVINCIA SELECCIONADA
-(void) OptionsSearchTableViewController: (XPSOptionsSearchTableViewController *) optionsVC
                    didSelectedProvincia: (NSString *) provincia
                               indexPath: (NSIndexPath *) indexPath

{
    if ([provincia isEqualToString:@"Totes les provincies"]) {
        
        self.provincia = @"tots";
        
    } else {
        
        self.provincia = provincia;
    }
    
    //POSAR PROVÍNCIA SELECCIONADA A LA CELL PER DONAR FEEDBACK A L'USUARI DE LA OPCIÓ ESCOLLIDA
    UITableViewCell *cell = [self.tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:0 inSection:0]];
    cell.textLabel.text = [NSString stringWithFormat:@"Província: %@", self.provincia];
    
    self.provinciaSelected = indexPath;
}

//MÈTODE DELEGAT PER OBTENIR INFORMACIÓ DEL POBLE SELECCIONAT
-(void) OptionsSearchTableViewController: (XPSOptionsSearchTableViewController *) optionsVC
                        didSelectedPoble: (NSString *) poble
                               indexPath: (NSIndexPath *) indexPath
{
    if ([poble isEqualToString:@"Tots els pobles"]) {
        
        self.poble = @"tots";
        
    } else {
        
        self.poble = poble;
        
    }
    
    //POSAR POBLE SELECCIONAT A LA CELL PER DONAR FEEDBACK A L'USUARI DE LA OPCIÓ ESCOLLIDA
    UITableViewCell *cell = [self.tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:1 inSection:0]];
    cell.textLabel.text = [NSString stringWithFormat:@"Poble: %@", self.poble];
    
    self.pobleSelected = indexPath;
}

//MÈTODE DELEGAT PER OBTENIR INFORMACIÓ DE LA CATEGORIA SELECCIONADA
-(void) OptionsSearchTableViewController: (XPSOptionsSearchTableViewController *) optionsVC
                     didSelectedCategory: (NSString *) categoria
                               indexPath: (NSIndexPath *) indexPath
{
    if ([categoria isEqualToString:@"Totes les categories"]) {
        
        self.category = @"tots";
        
    } else {
        
        self.category = categoria;
        
    }
    
    self.categorySelected = indexPath;
    
    //POSAR CATEGORIA SELECCIONADA A LA CELL PER DONAR FEEDBACK A L'USUARI DE LA OPCIÓ ESCOLLIDA
    UITableViewCell *cell = [self.tableView cellForRowAtIndexPath:[NSIndexPath indexPathForRow:0 inSection:1]];
    cell.textLabel.text = [NSString stringWithFormat:@"Categoria: %@", self.category];
}

#pragma mark NSURLConnection Delegate Methods

-(void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response
{
    self.responseData = [[NSMutableData alloc] init];
}

-(void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data
{
    [self.responseData appendData:data];
}

-(NSCachedURLResponse *)connection:(NSURLConnection *)connection willCacheResponse:(NSCachedURLResponse *)cachedResponse
{
    return nil;
}

-(void)connectionDidFinishLoading:(NSURLConnection *)connection
{
    //DADES REBUDES PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    NSMutableArray *activitats = [[NSMutableArray alloc] init];
    NSError *error;
    
    if (self.responseData != nil) { //S'HAN REBUT DADES
        
        //OBTENIM EL VALOR DE LES DADES REBUDES
        NSArray *JSONObjects = [NSJSONSerialization JSONObjectWithData:self.responseData
                                                               options:NSJSONReadingAllowFragments
                                                                 error:&error];
        
        
        //SÓN DADES D'ACTIVITATS
        if (JSONObjects != nil && [[JSONObjects objectAtIndex:0] isKindOfClass:[NSDictionary class]]) {
            
            for (NSDictionary *dict in JSONObjects) { //RECORREM CADA ACTIVITAT REBUDA
                
                //CREA ACTIVITAT I LA AFEGEIX AL ARRAY
                XPSActivityModel *activitat = [[XPSActivityModel alloc] initwithDictionary:dict];
                [activitats addObject:activitat];
                
            }
            
            //INICIA TAULA AMB RESULTATS DE LA CERCA
            XPSActivitiesListTableViewController *activityListVC = [[XPSActivitiesListTableViewController alloc] initWithStyle:UITableViewStylePlain withArray:activitats];
            
            //MOSTRA LA VISTA AMB ELS RESULTATS
            [self.navigationController pushViewController:activityListVC animated:YES];
            
        } else if ([[JSONObjects objectAtIndex:0] isEqualToString:@"0"]) { //NO HI HA ACTIVITATS
            
            UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                               message:@"No hi ha activitats amb els filtres seleccionats"
                                                              delegate:self
                                                     cancelButtonTitle:@"OK"
                                                     otherButtonTitles:nil];
            [theAlert show];
            
        }
        
    } else { //NO S'HAN REBUT DADES
        
        UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                           message:@"Problema amb la connexió. No s'ha pogut obtenir informació de les activitats"
                                                          delegate:self
                                                 cancelButtonTitle:@"OK"
                                                 otherButtonTitles:nil];
        [theAlert show];
        
    }
    
    //ACTUALITZACIÓ DADES DE LA TAULA
    [self.tableView reloadData];
    
}

-(void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error
{
    //ERROR PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    //MOSTRAR ALERTA
    UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                       message:@"Problema amb la connexió. No s'ha pogut obtenir informació de les acvtivitats"
                                                      delegate:self
                                             cancelButtonTitle:@"OK"
                                             otherButtonTitles:nil];
    [theAlert show];
}


@end
