/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSLoginViewController.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 4/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSLoginViewController.h"
#import "XPSActivityModel.h"

@interface XPSLoginViewController ()

@property (strong, nonatomic) UIActivityIndicatorView *ai;

@end

@implementation XPSLoginViewController

-(id) init
{
    //ASSIGNEM TÍTOL A LA VISTA
    if (self = [super init]) {
        self.title = @"Identifica't";
    }
    
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    
    self.navigationController.navigationBar.tintColor = [UIColor whiteColor];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(IBAction)login:(id)sender
{
    //PREPARACIO SOL·LICITUD AL SERVEI WEB AFEGIR NOU USUARI
    NSString *userData = [NSString stringWithFormat:@"mail=%@&password=%@", self.mail.text, self.password.text];
    NSData *postUserData = [userData dataUsingEncoding:NSUTF8StringEncoding];
    NSString *postLength = [NSString stringWithFormat:@"%lu", (unsigned long)[postUserData length]];
    
    NSMutableURLRequest *request = [[NSMutableURLRequest alloc] init];
    [request setURL:[NSURL URLWithString:@"http://gacc.esy.es/login.php"]];
    [request setHTTPMethod:@"POST"];
    [request setValue:postLength forHTTPHeaderField:@"Content-Length"];
    [request setValue:@"application/x-www-form-urlencoded" forHTTPHeaderField:@"Content-Type"];
    [request setHTTPBody:postUserData];
    
    //CONNEXIO ASÍNCRONA
    NSURLConnection *conn = [[NSURLConnection alloc] initWithRequest:request delegate:self];
    [conn start];
    
    //INDICADOR PER DONCAR FEEDBACK A L'USUARI QUE S'ESTAN CARREGANT LES DADES
    self.ai = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    self.ai.frame = CGRectMake(self.view.frame.size.width / 2.0, (self.view.frame.size.height / 2) - 150, 0, 0);
    CGAffineTransform transform = CGAffineTransformMakeScale(2.0f, 2.0f);
    self.ai.transform = transform;
    [self.ai startAnimating];
    [self.view addSubview:self.ai];
    
}

//MÈTODE PER AMAGAR TECLAT QUAN ES PREM SOBRE ALGUN PUNT DE LA PANTALLA
- (void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event
{
    [[self view] endEditing:YES];
}

#pragma mark NSURLConnection Delegate Methods

-(void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response
{
    self.responseData = [[NSMutableData alloc] init];
}

-(void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data
{
    [self.responseData appendData:data];
}

-(NSCachedURLResponse *)connection:(NSURLConnection *)connection willCacheResponse:(NSCachedURLResponse *)cachedResponse
{
    return nil;
}

-(void)connectionDidFinishLoading:(NSURLConnection *)connection
{
    //DADES REBUDES PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    NSError *error;
    
    if (self.responseData != nil) { //S'HAN REBUT DADES
        
        //OBTENIM EL VALOR DE LES DADES REBUDES
        NSArray *JSONObjects = [NSJSONSerialization JSONObjectWithData:self.responseData
                                                               options:NSJSONReadingAllowFragments
                                                                 error:&error];
        
        
        if ([JSONObjects count] > 0 && [[JSONObjects objectAtIndex:0] isEqual: @"0"]) { //NO S'HA POGUT FER EL LOGIN
            
            UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                               message:@"Login incorrecte"
                                                              delegate:self
                                                     cancelButtonTitle:@"OK"
                                                     otherButtonTitles:nil];
            [theAlert show];
            
        } else { //LOGIN CORRECTE
            
            //GUARDEM DADES DE L'USUARI A NSUSERDEFAULTS
            NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
            [defaults setObject:self.mail.text forKey:@"userMail"];
            
            //OBTENIM DADES DE LES ACTIVITATS PREFERIDES I LES GUARDEMA A NSUSERDEFAULTS
            NSMutableArray *activitats = [[NSMutableArray alloc] init];
            
            for (NSDictionary *dict in JSONObjects) {
                
                XPSActivityModel *activitat = [[XPSActivityModel alloc] initwithDictionary:dict];
                [activitats addObject:activitat];
            }
            
            NSData *encodedArray = [NSKeyedArchiver archivedDataWithRootObject:activitats];
            
            [defaults setObject:encodedArray forKey:@"favorits"];
            [defaults synchronize];
            
            //TORNM A LA PANTALL D'INICI
            [self.navigationController popToRootViewControllerAnimated:YES];
        }
        
    } else { //NO S'HAN REBUT DADES
        
        UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                           message:@"Problema amb la connexió. No s'ha pogut comprobar l'usuari i la contrasenya"
                                                          delegate:self
                                                 cancelButtonTitle:@"OK"
                                                 otherButtonTitles:nil];
        [theAlert show];
        
    }
    
    
}

-(void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error
{
    //DADES REBUDES PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    //MOSTRAR MISSATGE DE ERROR
    UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                       message:@"Problema amb la connexió. No s'ha pogut fer el login"
                                                      delegate:self
                                             cancelButtonTitle:@"OK"
                                             otherButtonTitles:nil];
    [theAlert show];
}

@end
