/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSMapViewController.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 11/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSMapViewController.h"

@interface XPSMapViewController () <CLLocationManagerDelegate>

@property (nonatomic, strong) CLLocationManager *locationManager;
@property (nonatomic, strong) NSString *address;
@property CGFloat zoom;

@end

@implementation XPSMapViewController

CLPlacemark *thePlaceMark;
MKRoute *routeDetails;

-(id) initWithAddress:(NSString *) address
{
    
    if (self = [super init]) {
        _address = address;
    }
    
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Ruta" style:UIBarButtonItemStylePlain target:self action:@selector(getDirections)];
    self.zoom = 0.0;
    
    //INICIA LOCALITZADOR PER UBICAR USUARI AL MAPA
    self.locationManager = [[CLLocationManager alloc] init];
    self.locationManager.delegate = self;
    [self.locationManager requestWhenInUseAuthorization];
    [self.locationManager startUpdatingLocation];
    self.map.showsUserLocation = YES;
    
    //CERCA DE LOCALITZACIÓ DE L'ACTIVITAT A PARTIR DE LA SEVA ADREÇA
    CLGeocoder *geocoder = [[CLGeocoder alloc] init];
    [geocoder geocodeAddressString:self.address completionHandler:^(NSArray *placemarks, NSError *error) {
        if (placemarks && placemarks.count > 0) {
            thePlaceMark = [placemarks lastObject];
            CLPlacemark *topResult = [placemarks objectAtIndex:0];
            MKPlacemark *placemark = [[MKPlacemark alloc] initWithPlacemark:topResult];
            MKCoordinateRegion region = self.map.region;
            
            //BUSQUEM ZOOM NECESSARI PER MOSTRAR ACTIVITAT I USUARI AL MAPA
            MKCoordinateSpan locationSpan;
            //LATITUD CENTRE ENTRE USUARI I ACTIVITAT
            if (self.locationManager.location.coordinate.latitude > placemark.coordinate.latitude) {
                
                locationSpan.latitudeDelta = self.locationManager.location.coordinate.latitude - placemark.coordinate.latitude;
            
            } else {
                
                locationSpan.latitudeDelta = placemark.coordinate.latitude - self.locationManager.location.coordinate.latitude;
            
            }
            //LONGITUD CENTRE ENTRE USUARI I ACTIVITAT
            if (self.locationManager.location.coordinate.longitude > placemark.coordinate.longitude) {
                
                locationSpan.longitudeDelta = self.locationManager.location.coordinate.longitude - placemark.coordinate.longitude;
                
            } else {
                
                locationSpan.longitudeDelta = placemark.coordinate.longitude - self.locationManager.location.coordinate.longitude;
                
            }
            
            //BUSQUEM CENTRE ENTRE ACTIVITAT I POSICIÓ USUARI
            CLLocationCoordinate2D locationCenter;
            locationCenter.latitude = (placemark.coordinate.latitude + self.locationManager.location.coordinate.latitude) / 2;
            locationCenter.longitude = (placemark.coordinate.longitude + self.locationManager.location.coordinate.longitude) / 2;

            //HO POSEM A LA REGIÓ QUE ES MOSTRA AL MAPA
            region = MKCoordinateRegionMake(locationCenter, locationSpan);
            [self.map setRegion:region animated:YES];
            [self addAnnotation:placemark];
            
        }
    }];
    
    self.map.delegate = self;
    
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

//SELECTOR TIPUS DE MAPA
-(IBAction)setMapType:(UISegmentedControl *)sender
{
    switch (sender.selectedSegmentIndex) {
        case 0: //STANDARD
            self.map.mapType = MKMapTypeStandard;
            break;
        
        case 1: //SATEL·LIT
            self.map.mapType = MKMapTypeSatellite;
            break;
        
        case 2: //HIBRID
            self.map.mapType = MKMapTypeHybrid;
            break;
            
        default:
            break;
    }
}

-(IBAction)setZoomLevel:(UIStepper *)sender
{
    MKCoordinateRegion region = self.map.region;
    
    if (sender.value > self.zoom) {
        
        region.span.longitudeDelta /= 2;
        region.span.latitudeDelta /= 2;

    } else if (sender.value < self.zoom || sender.value == 0.0) {
        
        region.span.longitudeDelta *= 2;
        region.span.latitudeDelta *= 2;
        
    }
    
    [self.map setRegion:region animated:YES];
    self.zoom = sender.value;
    
}

//ACTUALITZACIÓ UBICACIÓ DE L'USUARI
-(void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations {

    CLLocation *oldLocation;
    if (locations.count > 1) {
        oldLocation = [locations objectAtIndex:locations.count-2];
    } else {
        oldLocation = nil;
    }

}

//LOCALITZACIÓ ACTIVITAT
- (void)addAnnotation:(CLPlacemark *)placemark {
    MKPointAnnotation *point = [[MKPointAnnotation alloc] init];
    point.coordinate = CLLocationCoordinate2DMake(placemark.location.coordinate.latitude, placemark.location.coordinate.longitude);
    point.title = [placemark.addressDictionary objectForKey:@"Street"];
    point.subtitle = [placemark.addressDictionary objectForKey:@"City"];
    [self.map addAnnotation:point];
}

//MÈTODE PER OBTENIR INDICACIONS PER ARRIBAR A L'ADREÇA DE L'ACTIVITAT
-(void)getDirections
{
    MKDirectionsRequest *directionsRequest = [[MKDirectionsRequest alloc] init];
    MKPlacemark *placemark = [[MKPlacemark alloc] initWithPlacemark:thePlaceMark];
    [directionsRequest setSource:[MKMapItem mapItemForCurrentLocation]];
    [directionsRequest setDestination:[[MKMapItem alloc] initWithPlacemark:placemark]];
    directionsRequest.transportType = MKDirectionsTransportTypeAutomobile;
    MKDirections *directions = [[MKDirections alloc] initWithRequest:directionsRequest];
    [directions calculateDirectionsWithCompletionHandler:^(MKDirectionsResponse *response, NSError *error) {
        if (error) {
            NSLog(@"Error %@", error.description);
        } else {
            routeDetails = response.routes.lastObject;
            [self.map addOverlay:routeDetails.polyline];
            //self.destinationLabel.text = [placemark.addressDictionary objectForKey:@"Street"];
            //self.distanceLabel.text = [NSString stringWithFormat:@"%0.1f Miles", routeDetails.distance/1609.344];
            //self.transportLabel.text = [NSString stringWithFormat:@"%u" ,routeDetails.transportType];
            //self.allSteps = @"";
            /*for (int i = 0; i < routeDetails.steps.count; i++) {
                MKRouteStep *step = [routeDetails.steps objectAtIndex:i];
                NSString *newStep = step.instructions;
                self.allSteps = [self.allSteps stringByAppendingString:newStep];
                self.allSteps = [self.allSteps stringByAppendingString:@"\n\n"];
                self.steps.text = self.allSteps;
            }*/
        }
    }];
}

-(MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id<MKAnnotation>)annotation
{
    //TORNA NIL SI ES LA POSICÓ DE L'USUARI
    if ([annotation isKindOfClass:[MKUserLocation class]])  {
        return nil;
    }
    
    
    //LOCALITZACIÓ ACTIVITATS
    if ([annotation isKindOfClass:[MKPointAnnotation class]]) {
        
        //REUTILITZAR ANOTACIÓ SI ÉS POSSIBLE
        MKPinAnnotationView *pinView = (MKPinAnnotationView*)[self.map dequeueReusableAnnotationViewWithIdentifier:@"CustomPinAnnotationView"];
        
        if (!pinView) {
            //SI NO ES POT REUTILITZAR ES CREA UN DE NOU
            pinView = [[MKPinAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:@"CustomPinAnnotationView"];
            pinView.canShowCallout = YES;
        
        } else {
            
            pinView.annotation = annotation;
        
        }
        
        return pinView;
        
    }
    
    return nil;
}

//MOSTRAR TRAÇAT AL MAPA
-(MKOverlayRenderer *)mapView:(MKMapView *)mapView rendererForOverlay:(id<MKOverlay>)overlay
{
    MKPolylineRenderer  *routeLineRenderer = [[MKPolylineRenderer alloc] initWithPolyline:routeDetails.polyline];
    routeLineRenderer.strokeColor = [UIColor redColor];
    routeLineRenderer.lineWidth = 5;
    return routeLineRenderer;
}

@end
