/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSNearActivitiesTableViewController.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 4/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSNearActivitiesTableViewController.h"
#import "XPSActivityModel.h"
#import "XPSActivityViewController.h"
#import "CustomCell.h"
#import "../SDWebImage/UIImageView+WebCache.h"


@interface XPSNearActivitiesTableViewController () <CLLocationManagerDelegate>

//PROPIETATS USADES PER OBTENIR DADES DE LES ACTIVITATS MÉS PROPERES
@property (strong, nonatomic) NSArray *activities;
@property (strong, nonatomic) CLLocationManager* locationManager;
@property float latitude;
@property float longitude;

//FEEDBACK PER L'USUARI PER QUE SAPIGA QUE L'APLICA ESTÀ CARREGANT LES DADES
@property (strong, nonatomic) UIActivityIndicatorView *ai;

@end

@implementation XPSNearActivitiesTableViewController

-(id)initWithStyle:(UITableViewStyle)style
{
    if (self = [super initWithStyle:style]) {
        
        //ASSIGNEM TÍTOL I IMATGE PER L'ITEM DEL TAB BAR
        self.title = @"A prop";
        [self.tabBarItem setImage:[UIImage imageNamed:@"near"]];
        
        [self.tabBarItem setImage:[[UIImage imageNamed:@"near"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
        [self.tabBarItem setSelectedImage:[[UIImage imageNamed:@"nearB"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
        [self.tabBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: [UIColor blackColor]} forState:UIControlStateNormal];
        [self.tabBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: [UIColor whiteColor]} forState:UIControlStateSelected];
        
        //INICIEM LOCALITZADOR
        self.locationManager = [[CLLocationManager alloc] init];
        self.locationManager.delegate = self;
        [self.locationManager requestWhenInUseAuthorization];
        [self.locationManager startUpdatingLocation];
        
    }
    
    return self;
}

//LA SOL·LICITUD D'ACTIVITATS ES FA SEMPRE QUE APAREIX LA VISTA DE FORMA QUE SEMPRE ES TENEN LES ACTIVITATS MÉS PROPERES
-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    //PREPARACIÓ DE LA PETICIÓ AL SERVEI WEB AMB LES DADES DE LOCALITZACIÓ DE L'USUARI
    NSURLRequest *request = [NSURLRequest requestWithURL:[NSURL URLWithString:[NSString stringWithFormat:@"http://gacc.esy.es/consulta_proximitat.php?latitud=%f&longitud=%f", self.latitude, self.longitude]]];
    
    //CONNEXIO ASÍNCRONA
    NSURLConnection *conn = [[NSURLConnection alloc] initWithRequest:request delegate:self];
    [conn start];
    
    //INDICADOR PER DONCAR FEEDBACK A L'USUARI QUE S'ESTAN CARREGANT LES DADES
    self.ai = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    self.ai.frame = CGRectMake(self.view.frame.size.width / 2.0, (self.view.frame.size.height / 2) - 150, 0, 0);
    CGAffineTransform transform = CGAffineTransformMakeScale(2.0f, 2.0f);
    self.ai.transform = transform;
    [self.ai startAnimating];
    [self.view addSubview:self.ai];
    
    //ACTUALITZACIÓ DADES DE LA TAULA
    [self.tableView reloadData];
    
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    
    
    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
    
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {

    // Return the number of sections.
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    //NOMBRE ACTIVITATS REBUDES DEL SERVEI WEB I EMMAGATZEMADES A LA PROPIETAT ACTIVITIES
    return [self.activities count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    CustomCell *cell = [tableView dequeueReusableCellWithIdentifier:@"customCell"];
    
    if (!cell) {
        [tableView registerNib:[UINib nibWithNibName:@"CustomCell" bundle:nil] forCellReuseIdentifier:@"customCell"];
        cell = [tableView dequeueReusableCellWithIdentifier:@"customCell"];
    }
    
    //RECUPEREM ACTIVITAT
    XPSActivityModel *activity = [self.activities objectAtIndex:indexPath.row];
    
    cell.name.text = activity.name;
    cell.category.text = activity.category;
    NSString *formattedDistance = [NSString stringWithFormat:@"%@", activity.distance];
    cell.place.text = [NSString stringWithFormat:@"%@\n%@\nDistància: %@ Km", activity.place, activity.city, formattedDistance];
    
    //COMPROVACIÓ PER ESTAR SEGURS QUE ES CARREGA LA IMATGE CORRECTAMENT JA QUE LA RUTA PROPORCIONADA
    //DES DE LA FONT DE DADES I LA RUTA REAL SÓN DIFERENTS
    NSString *url = [NSString stringWithFormat:@"%@", activity.photoURL];
    NSRange agenda = [url rangeOfString:@"agenda/"];
    
    if (agenda.location != NSNotFound) {
        url = [url stringByReplacingCharactersInRange:agenda withString:@""];
        NSURL *theURL = [NSURL URLWithString:url];
        [cell.photo sd_setImageWithURL:theURL placeholderImage:[UIImage imageNamed:@"image"]];
    } else {
        
        [cell.photo sd_setImageWithURL:activity.photoURL placeholderImage:[UIImage imageNamed:@"image"]];
    }
 
    return cell;
}


-(void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    
    //S'OBTE L'ACTIVITAT SELECCIONADA
    XPSActivityModel *activity = [self.activities objectAtIndex:indexPath.row];
    
    //ES CREA LA VISTA AMB L'ACTIVITAT SELECCIONADA
    XPSActivityViewController *activityVC = [[XPSActivityViewController alloc] initWithModel:activity];
    
    //ES MOSTRA LA VISTA DE L'ACTIVITAT
    [self.navigationController pushViewController:activityVC animated:YES];
    
}

-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return 137.0;
}

//MÈTODE QUE ACTUALITZA POSICIÓ DE L'USUARI
-(void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations
{
    CLLocation* loc = [locations lastObject];
    self.latitude = loc.coordinate.latitude;
    self.longitude = loc.coordinate.longitude;
    
}

#pragma mark NSURLConnection Delegate Methods

-(void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response
{
    self.responseData = [[NSMutableData alloc] init];
}

-(void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data
{
    [self.responseData appendData:data];
}

-(NSCachedURLResponse *)connection:(NSURLConnection *)connection willCacheResponse:(NSCachedURLResponse *)cachedResponse
{
    return nil;
}

-(void)connectionDidFinishLoading:(NSURLConnection *)connection
{
    //DADES REBUDES PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    NSMutableArray *activitats = [[NSMutableArray alloc] init];
    NSError *error;
    
    if (self.responseData != nil) { //S'HAN REBUT DADES
        
        //OBTENIM EL VALOR DE LES DADES REBUDES
        NSArray *JSONObjects = [NSJSONSerialization JSONObjectWithData:self.responseData
                                                               options:NSJSONReadingAllowFragments
                                                                 error:&error];
        
        
        if (JSONObjects != nil) {
            
            for (NSDictionary *dict in JSONObjects) { //RECORREM CADA ACTIVITAT REBUDA
                
                //CREA ACTIVITAT I LA AFEGEIX AL ARRAY
                XPSActivityModel *activitat = [[XPSActivityModel alloc] initwithDictionary:dict];
                [activitats addObject:activitat];
            }
            
            //ASSIGNAR TOTES LES ACTIVITATS AL ARRAY QUE UTILITZA LA TAULA
            self.activities = activitats;
            
        }
        
    } else { //NO S'HAN REBUT DADES
        
        UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                           message:@"Problema amb la connexió. No s'ha pogut obtenir informació de les acvtivitats"
                                                          delegate:self
                                                 cancelButtonTitle:@"OK"
                                                 otherButtonTitles:nil];
        [theAlert show];
        
    }
    
    //ACTUALITZEM DADES DE LA TAULA
    [self.tableView reloadData];

}

-(void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error
{
    //ERROR PER TANT FINALITZA FEEDBACK
    [self.ai stopAnimating];
    [self.ai removeFromSuperview];
    
    //MOSTRAR ALERTA
    UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                       message:@"Problema amb la connexió. No s'ha pogut obtenir informació de les acvtivitats"
                                                      delegate:self
                                             cancelButtonTitle:@"OK"
                                             otherButtonTitles:nil];
    [theAlert show];
}


@end
