/*
 This file is part of GACC.
 
 GACC is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 GACC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
//
//  XPSProfileTableViewController.m
//  Gacc
//
//  Created by Xavi Pregona Soto on 4/5/15.
//  Copyright (c) 2015 XPS. All rights reserved.
//

#import "XPSProfileTableViewController.h"
#import "XPSActivityModel.h"
#import "XPSActivityViewController.h"
#import "IniciViewController.h"
#import "CustomCell.h"
#import "../SDWebImage/UIImageView+WebCache.h"

@interface XPSProfileTableViewController ()

@end

@implementation XPSProfileTableViewController

-(id)initWithStyle:(UITableViewStyle)style
{
    //ASSIGNEM TÍTOL I IMATGE PER L'ITEM DEL TAB BAR
    if (self = [super initWithStyle:style]) {
        self.title = @"Perfil";
        [self.tabBarItem setImage:[UIImage imageNamed:@"profile"]];
        
        [self.tabBarItem setImage:[[UIImage imageNamed:@"user"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
        [self.tabBarItem setSelectedImage:[[UIImage imageNamed:@"userB"] imageWithRenderingMode:UIImageRenderingModeAlwaysOriginal]];
        [self.tabBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: [UIColor blackColor]} forState:UIControlStateNormal];
        [self.tabBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: [UIColor whiteColor]} forState:UIControlStateSelected];
    }
    
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.navigationController.navigationBar.tintColor = [UIColor whiteColor];
    
    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
    
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    //AQUESTA VISTA NOMÉS MOSTRA INFORMACIÓ SI L'USUARI ESTÀ IDENTIFICAT AL SISTEMA
    //MOSTRA UN MISSATGE D'ALERTA EN CAS DE NO HAVER FET LOGIN
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    
    if (![defaults objectForKey:@"userMail"]) { //USUARI SENSE IDENTIFICAR
        
        UIAlertView *theAlert = [[UIAlertView alloc] initWithTitle:@"Error"
                                                           message:@"Cal estar identificat per gestionar el teu perfil"
                                                          delegate:self
                                                 cancelButtonTitle:@"OK"
                                                 otherButtonTitles:nil];
        [theAlert show];
        
    
    } else { //USUARI IDENTIFICAT
        
        self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Logout" style:UIBarButtonItemStylePlain target:self action:@selector(logout)];
        
        //RECARREGA DADES DE LA TAULA PER ACTUALITZAR INFORMACIÓ EN CAS D'HAVER AFEGIT/ELIMNAT ACTIVITATS
        [self.tableView reloadData];
    
    }
    
    
}

#pragma mark - utils

-(void)logout
{
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    [defaults removeObjectForKey:@"userMail"];
    [defaults removeObjectForKey:@"favorits"];
    [self.tableView reloadData];
    
    NSArray *vc = [self.tabBarController viewControllers];
    
    [self.tabBarController setSelectedViewController:[vc objectAtIndex:0]];
    

}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {

    // Return the number of sections.
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {

    //ES CONSULTA EL NOMBRE D'ACTIVITATS FAVORITES A NSUSERDEFAULTS
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    NSData *encodedData = [defaults objectForKey:@"favorits"];
    NSArray *activitats = (NSArray *)[NSKeyedUnarchiver unarchiveObjectWithData:encodedData];
    
    // Return the number of rows in the section.
    return [activitats count];
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    //ES RECUPERA INFORMACIÓ DE LES ACTIVITATS FAVORITES
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    NSData *encodedData = [defaults objectForKey:@"favorits"];
    NSArray *activitats = (NSArray *)[NSKeyedUnarchiver unarchiveObjectWithData:encodedData];
    
    //static NSString *cellIdentifier = @"activityCell";
    
    
    CustomCell *cell = [tableView dequeueReusableCellWithIdentifier:@"customCell"];
    
    if (!cell) {
        [tableView registerNib:[UINib nibWithNibName:@"CustomCell" bundle:nil] forCellReuseIdentifier:@"customCell"];
        cell = [tableView dequeueReusableCellWithIdentifier:@"customCell"];
    }
    
    //RECUPEREM ACTIVITAT
    XPSActivityModel *activity = [activitats objectAtIndex:indexPath.row];
    
    cell.name.text = activity.name;
    cell.category.text = activity.category;
    cell.place.text = [NSString stringWithFormat:@"%@\n%@", activity.place, activity.city];
    
    //COMPROVACIÓ PER ESTAR SEGURS QUE ES CARREGA LA IMATGE CORRECTAMENT JA QUE LA RUTA PROPORCIONADA
    //DES DE LA FONT DE DADES I LA RUTA REAL SÓN DIFERENTS
    NSString *url = [NSString stringWithFormat:@"%@", activity.photoURL];
    NSRange agenda = [url rangeOfString:@"agenda/"];
    
    if (agenda.location != NSNotFound) {
        url = [url stringByReplacingCharactersInRange:agenda withString:@""];
        NSURL *theURL = [NSURL URLWithString:url];
        [cell.photo sd_setImageWithURL:theURL placeholderImage:[UIImage imageNamed:@"image"]];
    } else {
        
        [cell.photo sd_setImageWithURL:activity.photoURL placeholderImage:[UIImage imageNamed:@"image"]];
    }

    return cell;

}

-(void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    //ES RECUPERA INFORMACIÓ DE LES ACTIVITATS FAVORITES
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    NSData *encodedData = [defaults objectForKey:@"favorits"];
    NSArray *activitats = (NSArray *)[NSKeyedUnarchiver unarchiveObjectWithData:encodedData];
    
    //S'OBTE L'ACTIVITAT SELECCIONADA
    XPSActivityModel *activity = [activitats objectAtIndex:indexPath.row];
    
    //ES CREA LA VISTA AMB L'ACTIVITAT SELECCIONADA
    XPSActivityViewController *activityVC = [[XPSActivityViewController alloc] initWithModel:activity];
    
    //ES MOSTRA LA VISTA DE L'ACTIVITAT
    [self.navigationController pushViewController:activityVC animated:YES];
    
}

//TÍTOL DE LA TAULA
- (NSString *)tableView:(UITableView *)tableView
titleForHeaderInSection:(NSInteger)section {
    
    return @"Activitats favorites";
    
}

-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return 137.0;
}
@end
